@@ -10,7 +10,7 @@ def download_from_google_images(keywords : str, limit : int, class_name : str):
         print('Too much images.')
         return
 
-    if class_name.contains(" "):
+    if ' ' in class_name:
         print("Class names can't contains spaces.")
 
     os.makedirs("dataset", exist_ok=True)
